################################################################################
#
# Options generales des Makefiles
#
################################################################################
#     #          # 
# DGU # 08.11.07 # Creation
#     #          #  
################################################################################

SHELL=/bin/csh
MAKE=make
GCC ?= gcc

CXX=$(GCC)
OPTS_AR=r
RANLIB=ranlib

ifeq ($(findstring 64, $(MACHTYPE)),64)
  TF_OS=$(SCROS)64
else
  TF_OS=$(SCROS)
endif

TTFBIN=$(OCC_ROOT)/bin/$(TF_OS)
TTFOBJ=$(OCC_ROOT)/obj/$(TF_OS)

CMN_RELDEB=-DTF_FINAL_RELEASE
OPT_RELDEB=-O2

ifeq ($(findstring -g, $(TTFSPEC_C)),-g)
  TTFBIN=$(OCC_ROOT)/bin/$(TF_OS).dbg
  TTFOBJ=$(OCC_ROOT)/obj/$(TF_OS).dbg
  OPT_RELDEB=-O0
endif

CMN_OCC_SETS = -DCSFDB -DHAVE_NO_DLL -DHAVE_LIMITS_H -DHAVE_IOSTREAM_H -DHAVE_SYS_MMAN_H \
-DHAVE_SYS_DIR_H -DHAVE_DIRENT_H -DHAVE_IOMANIP

ifeq ($(TF_OS), Solaris)
  OS_OCC_SETS= -DHAVE_SYS_SYSTEMINFO_H	
endif
ifeq ($(TF_OS), HPUX)
  OS_OCC_SETS= -DHAVE_SYS_UTSNAME_H	
endif

#  Common flags when in gcc use 
# EXPLICATIONS des options:
#
# -fcheck-new: anti-warning: `operator new' must not return NULL unless it is declared `throw()'
#  -Wall: enables all warnings
# -w: no warnings
#  -Wno-deprecated: Do not warn about usage of deprecated features
# -pthread: Adds support for multithreading with the pthreads library.
# -fPIC:independent position code: indispensable pour HPUX (y compris lors du link)
#  -fno-strict-aliasing: allows cast between different size types
#  -fno-rtti: Disable generation of information about every class with virtual functions
CMN_CCFLAGS=-fPIC -Wall -pedantic -fno-strict-aliasing
CMN_CXXFLAGS=-fPIC -Wno-deprecated -fcheck-new -fno-rtti

# Options par plateforme

   #      ###   #     #
  # #      #     #   #
 #   #     #      # #
#     #    #       #
#######    #      # #
#     #    #     #   #
#     #   ###   #     #

#  Version 7.0 installation de gcc.3.3.2 sur ase16, et utilisation de xlC par defaut
# -qnooptimize(xlC): -O0: pas d'optimisation NECESSAIRE pour xlC qui fait n'importe quoi avec les PtrHas
# -qcpluscmt(xlC): autorise commentaires // dans du C
# -qsrcmsg(xlC): a priori + d'infos pour les warnings (pas sur)
# -bmaxdata:0x80000000(xlC): augmentation taille CDATA (demande explicite CD-ADAPCO)
# -qstaticinline(xlC): plus de multiply defined lors du link...
#
ifeq ($(TF_OS), AIX)
  ifneq ($(findstring GCC_AIX, $(TTFSPEC_C)),GCC_AIX)
    CXX=/usr/vacpp/bin/xlC
    CMN_CCFLAGS=
    CMN_CXXFLAGS=
    OS_CC_FLAGS=-qnolm -DXLC_AIX -qcpluscmt -ma -w -qstrict -qnooptimize -qsrcmsg
    OS_CXX_FLAGS=$(OS_CC_FLAGS) -bmaxdata:0x80000000 -qstaticinline
  else
    OS_CC_FLAGS=-I/usr/local/lib/gcc-lib/powerpc-ibm-aix4.3.3.0/3.3.2/include
    OS_CXX_FLAGS=$(OS_CC_FLAGS)
  endif
endif

  ###   ######    ###   #     #
   #    #     #    #     #   #
   #    #     #    #      # #
   #    ######     #       #
   #    #   #      #      # #
   #    #    #     #     #   #
  ###   #     #   ###   #     #

#  DGU 14/10/2005
#  Suite changement de machine ttfsg8 (gcc 2.95.3) en ttfsg9 (gcc 3.3.2) reprobleme de multiGOT. 
# Info pechee sur le net (merci le net):
#  mettre LD_LAYOUT:lgot_buffer a 1024 et non 20 comme le reclame le compilateur, et le mettre en flag sur 
#  la compilation et non seulement au link.
ifeq ($(TF_OS), IRIX)
  CXX=ccache gcc
#  OS_CXX_FLAGS=$(CMN_CXXFLAGS) -Wa,-G0 -Wa,-g0 -LD_LAYOUT:lgot_buffer=1024 -I/usr/local/lib/gcc-lib/mips-sgi-irix6.5/3.3.2/include
  OS_CC_FLAGS=-I/usr/local/lib/gcc-lib/mips-sgi-irix6.5/3.3.2/include -fsigned-char
  OS_CXX_FLAGS=$(OS_CC_FLAGS)
  RANLIB=file
  OPT_RELDEB=-O0
endif

#     # ######          #     # #     #
#     # #     #         #     #  #   #
#     # #     #         #     #   # #
####### ######   #####  #     #    #
#     # #               #     #   # #
#     # #               #     #  #   #
#     # #                #####  #     #

ifeq ($(TF_OS), HPUX)
  ifeq ($(findstring aCC, $(TTFSPEC_C)),aCC)
    CXX=/opt/aCC/bin/aCC 
    OS_CC_FLAGS=-O -w
    OS_CXX_FLAGS=$(OS_CC_FLAGS)
  else
    OS_CC_FLAGS=-pthread -I/usr/local/lib/gcc-lib/hppa2.0n-hp-hpux11.00/3.3.2/include
    OS_CXX_FLAGS=$(OS_CC_FLAGS)
    OPT_RELDEB=-O0
  endif
endif

 #####
#     #   ####   #         ##    #####      #     ####
#        #    #  #        #  #   #    #     #    #
 #####   #    #  #       #    #  #    #     #     ####
      #  #    #  #       ######  #####      #         #
#     #  #    #  #       #    #  #   #      #    #    #
 #####    ####   ######  #    #  #    #     #     ####

ifeq ($(TF_OS), Solaris)
  OS_CC_FLAGS=-I/usr/local/lib/gcc-lib/sparc-sun-solaris2.8/3.3.2/include
  OS_CXX_FLAGS=$(OS_CC_FLAGS)
  OPT_RELDEB=-O0
endif

#
#           #    #    #  #    #  #    #
#           #    ##   #  #    #   #  #
#           #    # #  #  #    #    ##
#           #    #  # #  #    #    ##
#           #    #   ##  #    #   #  #
#######     #    #    #   ####   #    #

ifeq ($(TF_OS), Linux)
  LINUX_VRS=$(shell gcc --version)
  OS_CC_FLAGS=-I/usr/local/lib/gcc-lib//i686-pc-linux-gnu/3.3.2/include
  OS_CXX_FLAGS=$(OS_CC_FLAGS)
endif

#                                           #####  #      
#           #    #    #  #    #  #    #    #     # #    # 
#           #    ##   #  #    #   #  #     #       #    # 
#           #    # #  #  #    #    ##      ######  #    # 
#           #    #  # #  #    #    ##      #     # #######
#           #    #   ##  #    #   #  #     #     #      # 
#######     #    #    #   ####   #    #     #####       # 

#  flag -w for C++ anti-warning mostly for bad cast (void* to/from int when using IwMapPtrToPtr)
#  That flag MUST BE ACTIVATED for general tracking. Compilation is set to be 32 bits
ifeq ($(TF_OS), Linux64)
  LINUX_VRS=$(shell gcc --version)
  OS_CC_FLAGS=-m32 -I/usr/lib/gcc-lib/i586-suse-linux/3.3.3/include/
  OS_CXX_FLAGS=-w $(OS_CC_FLAGS)
endif

   #      ###   #     #     #####  #      
  # #      #     #   #     #     # #    # 
 #   #     #      # #      #       #    # 
#     #    #       #       ######  #    # 
#######    #      # #      #     # #######
#     #    #     #   #     #     #      # 
#     #   ###   #     #     #####       # 

ifeq ($(TF_OS), AIX64)
  ifeq ($(findstring XLC, $(TTFSPEC_C)),XLC)
    CXX=/usr/vacpp/bin/xlC
    ifeq ($(findstring 64, $(OBJECT_MODE)),64)
      OS_CC_FLAGS=-qnolm -q64 -DXLC_AIX -qcpluscmt -ma
      OS_CXX_FLAGS=$(OS_CC_FLAGS)
    else
      CXX=__UNDEFINED_OBJECT_MODE__
    endif
  else
  endif
endif

  ###   ######    ###   #     #     #####  #      
   #    #     #    #     #   #     #     # #    # 
   #    #     #    #      # #      #       #    # 
   #    ######     #       #       ######  #    # 
   #    #   #      #      # #      #     # #######
   #    #    #     #     #   #     #     #      # 
  ###   #     #   ###   #     #     #####       # 

ifeq ($(TF_OS), IRIX64)
  ifeq ($(findstring SGICC, $(TTFRELDEB)),SGICC)
    CXX=cc
    CMN_CCFLAGS=
    CMN_CXXFLAGS=
    OS_CC_FLAGS=-64 -DCC_SGI -woff 1552
    OS_CXX_FLAGS=$(OS_CC_FLAGS)
  else
  endif
endif

#     # ######          #     # #     #     #####  #      
#     # #     #         #     #  #   #     #     # #    # 
#     # #     #         #     #   # #      #       #    # 
####### ######   #####  #     #    #       ######  #    # 
#     # #               #     #   # #      #     # #######
#     # #               #     #  #   #     #     #      # 
#     # #                #####  #     #     #####       # 

ifeq ($(TF_OS), HPUX64)
  OS_CC_FLAGS=-mlp64
  OS_CXX_FLAGS=$(OS_CC_FLAGS)
endif

#     #
##   ##    ##     ####
# # # #   #  #   #    #
#  #  #  #    #  #
#     #  ######  #
#     #  #    #  #    #
#     #  #    #   ####

ifeq ($(TF_OS), MAC_OS)
  OPTS_AR=-rS
endif

OPTS_CC=-c $(OS_CC_FLAGS) $(CMN_CCFLAGS) -D$(SCROS) $(TTFSPEC_C) $(OPT_RELDEB) $(CMN_RELDEB)
OPTS_CXX=-c $(OS_CXX_FLAGS) $(CMN_CXXFLAGS) -D$(SCROS) $(TTFSPEC_C) $(OPT_RELDEB) $(CMN_RELDEB)

